Welcome to the dfWinReg documentation
========================================

dfWinReg, or Digital Forensics Windows Registry, provides read-only access to
Windows Registry objects. The goal of dfWinReg is to provide a generic
interface for accessing Windows Registry objects that resembles the Registry
key hierarchy as seen on a live Windows system.

dfWinReg originates from the `Plaso project <https://github.com/log2timeline/plaso>`__
and is also based on ideas from the `winreg-kb project <https://github.com/libyal/winreg-kb>`__.
It was largely rewritten and made into a stand-alone project to provide more
flexibility and allow other projects to make use of Windows Registry
functionality.

The source code is available from the `project page <https://github.com/log2timeline/dfwinreg>`__.

.. toctree::
   :maxdepth: 2

   sources/user/index

.. toctree::
   :maxdepth: 2

   Code snippets <sources/Code-snippets>

.. toctree::
   :maxdepth: 2

   Supported formats <sources/Supported-formats>

.. toctree::
   :maxdepth: 2

   API documentation <sources/api/dfwinreg>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

